@@ -13,6 +13,7 @@ def result_model_mixin_factory(
     decimal_places: Optional[int] = None,
     max_digits: Optional[int] = None,
     validators: Optional[list] = None,
+    help_text: Optional[str] = None,
 ) -> Type[models.Model]:
     """Returns an abstract model class with a single field class"""
 
@@ -28,6 +29,7 @@ def result_model_mixin_factory(
         decimal_places,
         max_digits,
         validators,
+        help_text,
     ):
         AbstractModel.add_to_class(name, fld_cls)
     return AbstractModel
